summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'checksetup.pl')
-rwxr-xr-xchecksetup.pl19
1 files changed, 12 insertions, 7 deletions
diff --git a/checksetup.pl b/checksetup.pl
index ab7ea9f7a..cf124b8e2 100755
--- a/checksetup.pl
+++ b/checksetup.pl
@@ -1,4 +1,4 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -12,8 +12,10 @@
# Initialization
######################################################################
+use 5.10.1;
use strict;
-use 5.008001;
+use warnings;
+
use File::Basename;
BEGIN { chdir dirname($0); }
use lib qw(. lib);
@@ -52,14 +54,14 @@ my $answers_file = $ARGV[0];
my $silent = $answers_file && !$switch{'verbose'};
print(install_string('header', get_version_and_os()) . "\n") unless $silent;
-exit if $switch{'version'};
+exit 0 if $switch{'version'};
# Check required --MODULES--
my $module_results = check_requirements(!$silent);
Bugzilla::Install::Requirements::print_module_instructions(
$module_results, !$silent);
-exit if !$module_results->{pass};
+exit 1 if !$module_results->{pass};
# Break out if checking the modules is all we have been asked to do.
-exit if $switch{'check-modules'};
+exit 0 if $switch{'check-modules'};
###########################################################################
# Load Bugzilla Modules
@@ -108,7 +110,7 @@ my $lc_hash = Bugzilla->localconfig;
# At this point, localconfig is defined and is readable. So we know
# everything we need to create the DB. We have to create it early,
# because some data required to populate data/params is stored in the DB.
Bugzilla::DB::bz_check_requirements(!$silent);
Bugzilla::DB::bz_create_database() if $lc_hash->{'db_check'};
@@ -207,6 +209,9 @@ Bugzilla::Hook::process('install_before_final_checks', { silent => $silent });
# Final checks
###########################################################################
+# Clear all keys from Memcached
+Bugzilla->memcached->clear_all();
+
# Check if the default parameter for urlbase is still set, and if so, give
# notification that they should go and visit editparams.cgi
if (Bugzilla->params->{'urlbase'} eq '') {
@@ -360,7 +365,7 @@ L<Bugzilla::Install::Filesystem/create_htaccess>.
=item 9
-Updates the system parameters (stored in F<data/params>), using
+Updates the system parameters (stored in F<data/params.json>), using
L<Bugzilla::Config/update_params>.
=item 10
@@ -108,7 +110,7 @@ my $lc_hash = Bugzilla->localconfig;
# At this point, localconfig is defined and is readable. So we know
# everything we need to create the DB. We have to create it early,
-# because some data required to populate data/params is stored in the DB.
+# because some data required to populate data/params.json is stored in the DB.
Bugzilla::DB::bz_check_requirements(!$silent);
Bugzilla::DB::bz_create_database() if $lc_hash->{'db_check'};